totem r5356 - in branches/gnome-2-22: . src/plugins/youtube



Author: pwithnall
Date: Thu Apr 10 18:51:45 2008
New Revision: 5356
URL: http://svn.gnome.org/viewvc/totem?rev=5356&view=rev

Log:
2008-04-10  Philip Withnall  <pwithnall svn gnome org>

	* src/plugins/youtube/youtube.py: Fix check for soup plugin.
	(Closes: #522547)



Modified:
   branches/gnome-2-22/ChangeLog
   branches/gnome-2-22/src/plugins/youtube/youtube.py

Modified: branches/gnome-2-22/src/plugins/youtube/youtube.py
==============================================================================
--- branches/gnome-2-22/src/plugins/youtube/youtube.py	(original)
+++ branches/gnome-2-22/src/plugins/youtube/youtube.py	Thu Apr 10 18:51:45 2008
@@ -42,7 +42,7 @@
 		self.vadjust = {}
 		self.liststore = {}
 	def activate (self, totem_object):
 		"""Check for the availability of the flvdemux and souphttpsrc GStreamer plugins"""
 		bvw_name = totem_object.get_video_widget_backend_name ()
 
 		if bvw_name.find ("GStreamer") != -1:
@@ -52,7 +52,7 @@
 				import gst
 
 				registry = gst.registry_get_default ()
-				if registry.find_plugin ("flvdemux") == None or registry.find_plugin ("souphttpsrc") == None:
+				if registry.find_plugin ("flvdemux") == None or registry.find_plugin ("soup") == None:
 					"""This means an error will be displayed when they try to play anything"""
 					self.gstreamer_plugins_present = False
 			except ImportError:
@@ -42,7 +42,7 @@
 		self.liststore = {}
 	def activate (self, totem_object):
-		"""Check for the availability of the flvdemux and souphttpsrc GStreamer plugins"""
+		"""Check for the availability of the flvdemux and soup GStreamer plugins"""
 		bvw_name = totem_object.get_video_widget_backend_name ()
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]